@@ -1,11 +1,5 @@
 package YAML::Tag;
 
-use strict;
-use warnings;
-
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-
 use overload '""' => sub { ${$_[0]} };
 
 sub new {
